@@ -14,11 +14,11 @@
 
 #define EOG_CONF_FULLSCREEN_LOOP            "/apps/eog/full_screen/loop"
 #define EOG_CONF_FULLSCREEN_UPSCALE         "/apps/eog/full_screen/upscale"
-#define EOG_CONF_FULLSCREEN_AUTO_ADVANCE    "/apps/eog/full_screen/auto_advance"
 #define EOG_CONF_FULLSCREEN_SECONDS         "/apps/eog/full_screen/seconds"
 
 #define EOG_CONF_UI_TOOLBAR                  "/apps/eog/ui/toolbar"
 #define EOG_CONF_UI_STATUSBAR                "/apps/eog/ui/statusbar"
+#define EOG_CONF_UI_IMAGE_COLLECTION         "/apps/eog/ui/image_collection"
 #define EOG_CONF_UI_INFO_IMAGE               "/apps/eog/ui/info_image"
 #define EOG_CONF_UI_INFO_COLLECTION          "/apps/eog/ui/info_collection"
 
