@@ -88,7 +88,9 @@ eog_image_dispose (GObject *object)
 	
 	if (priv->toclean) {
 		g_free (priv->toclean);
-		gnome_vfs_monitor_cancel (priv->monitor_handle);
+		if (priv->monitor_handle != NULL) {
+			gnome_vfs_monitor_cancel (priv->monitor_handle);
+		}
 	}
 	
 	if (priv->uri) {
@@ -455,7 +457,8 @@ eog_image_determine_file_bytes (EogImage *img, GError **error)
 	info = gnome_vfs_file_info_new ();
 	result = gnome_vfs_get_file_info_uri (img->priv->uri,
 					      info,
-					      GNOME_VFS_FILE_INFO_DEFAULT);
+					      GNOME_VFS_FILE_INFO_DEFAULT |
+					      GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 
 	if ((result != GNOME_VFS_OK) || (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE) == 0) {
 		bytes = 0;
@@ -794,15 +797,24 @@ eog_image_real_load (EogImage *img, guint data2read, EogJob *job, GError **error
 		}
 	}
 
-	if (!gdk_pixbuf_loader_close (loader, error)) {
+	/* if we already failed ignore errors on close */
+	if (failed) {
+		gdk_pixbuf_loader_close (loader, NULL);
+	}
+	else if (!gdk_pixbuf_loader_close (loader, error)) {
 		failed = TRUE;
 	}
-	
+
 	g_free (buffer);
 	gnome_vfs_close (handle);
 	
 	failed = (failed || bytes_read_total == 0 || priv->cancel_loading);
 
+	if (*error != NULL) {
+		failed = TRUE;
+		priv->status = EOG_IMAGE_STATUS_FAILED;
+	}
+
 	if (priv->cancel_loading) {
 		priv->cancel_loading = FALSE;
 		failed = TRUE;
@@ -1772,8 +1784,8 @@ vfs_monitor_dir_cb (GnomeVFSMonitorHandle *handle,
           gpointer user_data)
 {
 	VfsFileCbContext *ctx = user_data;
-	gchar *monitor_ptr = monitor_uri;
-	gchar *info_ptr = info_uri;
+	gchar *monitor_ptr = (gchar *) monitor_uri;
+	gchar *info_ptr = (gchar *) info_uri;
 	
 	monitor_ptr += 7;
 	info_ptr += 7;
