@@ -728,6 +728,56 @@ eog_wrap_list_select_right (EogWrapList *wlist)
 	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
 }
 
+void
+eog_wrap_list_select_first (EogWrapList *wlist)
+{
+	EogWrapListPrivate *priv;
+	GList *node;
+	GnomeCanvasItem *item;
+
+	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
+
+	priv = wlist->priv;
+
+	node = g_list_first (priv->view_order);
+	if (node == NULL) return;
+
+	item = GNOME_CANVAS_ITEM (node->data);
+
+	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
+	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
+	priv->last_item_clicked = item;
+
+	ensure_item_is_visible (wlist, item);
+
+	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
+}
+
+void
+eog_wrap_list_select_last (EogWrapList *wlist)
+{
+	EogWrapListPrivate *priv;
+	GList *node;
+	GnomeCanvasItem *item;
+
+	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
+
+	priv = wlist->priv;
+
+	node = g_list_last (priv->view_order);
+	if (node == NULL) return;
+
+	item = GNOME_CANVAS_ITEM (node->data);
+
+	set_select_status (wlist, EOG_COLLECTION_ITEM (priv->last_item_clicked), FALSE);
+	set_select_status (wlist, EOG_COLLECTION_ITEM (item), TRUE);
+	priv->last_item_clicked = item;
+
+	ensure_item_is_visible (wlist, item);
+
+	g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
+}
+
 static gboolean 
 eog_wrap_list_key_press_cb (GtkWidget *widget, GdkEventKey *event)
 {
@@ -824,6 +874,7 @@ add_image (EogWrapList *wlist, EogImage *image)
 	priv = wlist->priv;
 	
 	item = eog_collection_item_new (gnome_canvas_root (GNOME_CANVAS (wlist)), image);
+	gnome_canvas_item_move (item, -1000.0, -1000.0); /* hide item in invisible area */
 	g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (handle_item_event), wlist);
 	g_signal_connect (G_OBJECT (item), "size_changed", G_CALLBACK (handle_item_size_changed), wlist);
 
@@ -831,18 +882,19 @@ add_image (EogWrapList *wlist, EogImage *image)
 }
 
 static void
-model_prepared (EogImageList *model, gpointer data)
+create_items_from_model (EogWrapList *wlist, EogImageList *model)
 {
-	EogWrapList *wlist;
 	EogWrapListPrivate *priv;
 	EogIter *iter;
 	gboolean success;
 	EogImage *image;
+	EogCollectionItem *initial_item;
 	GList *it;
+	int pos;
 	
-	g_return_if_fail (EOG_IS_WRAP_LIST (data));
+	g_return_if_fail (EOG_IS_WRAP_LIST (wlist));
+	g_return_if_fail (EOG_IS_IMAGE_LIST (model));
 
-	wlist = EOG_WRAP_LIST (data);
 	priv = wlist->priv;
 
 	g_assert (priv->view_order == NULL);
@@ -861,17 +913,21 @@ model_prepared (EogImageList *model, gpointer data)
 	priv->view_order = g_list_reverse (priv->view_order);
 	priv->n_items = g_list_length (priv->view_order);
 
-	priv->global_update_hints[GLOBAL_WIDGET_SIZE_CHANGED] = TRUE;
-	request_update (wlist);
-	
 	for (it = priv->view_order; it != NULL; it = it->next) {
 		eog_collection_item_load (EOG_COLLECTION_ITEM (it->data));
 	}
 
 	if (priv->view_order != NULL) {
 		deselect_all (wlist);
-		if (set_select_status (wlist, EOG_COLLECTION_ITEM (priv->view_order->data), TRUE)) {
-			priv->last_item_clicked = GNOME_CANVAS_ITEM (priv->view_order->data);
+
+		pos = eog_image_list_get_initial_pos (priv->model);
+		if (pos == -1) return;
+
+		initial_item = g_list_nth_data (priv->view_order, pos);
+
+		if (set_select_status (wlist, EOG_COLLECTION_ITEM (initial_item), TRUE)) {
+			priv->last_item_clicked = GNOME_CANVAS_ITEM (initial_item);
+			ensure_item_is_visible (wlist, GNOME_CANVAS_ITEM (initial_item));
 			g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
 		}
 	}
@@ -939,15 +995,8 @@ model_image_removed (EogImageList *model, int pos, gpointer data)
 	/* update item arrangement */
 	priv->global_update_hints[N_ITEMS_CHANGED] = TRUE;
 	request_update (wlist);
-
-	/* inform others */
-	if (selection_changed) {
-		g_signal_emit (G_OBJECT (wlist), eog_wrap_list_signals [SELECTION_CHANGED], 0);
-	}
 }
 
-
-
 /* Set model handler for the wrapped list view */
 void
 eog_wrap_list_set_model (EogWrapList *wlist, EogImageList *model)
@@ -983,12 +1032,7 @@ eog_wrap_list_set_model (EogWrapList *wlist, EogImageList *model)
 	if (model) {
 		priv->model = model;
 		g_object_ref (G_OBJECT (model));
-
-		priv->model_ids[MODEL_SIGNAL_PREPARED] = g_signal_connect (
-			G_OBJECT (model), "list-prepared",
-			G_CALLBACK (model_prepared),
-			wlist);
-
+		
 		priv->model_ids[MODEL_SIGNAL_IMAGE_ADDED] = g_signal_connect (
 			G_OBJECT (model), "image-added",
 			G_CALLBACK (model_image_added),
@@ -998,8 +1042,11 @@ eog_wrap_list_set_model (EogWrapList *wlist, EogImageList *model)
 			G_OBJECT (model), "image-removed",
 			G_CALLBACK (model_image_removed),
 			wlist);
+		
+		create_items_from_model (wlist, model);
 	}
 
+	priv->global_update_hints[N_ITEMS_CHANGED] = TRUE;
 	request_update (wlist);
 }
 
